@@ -14,15 +14,12 @@ extern crate clap;
 #[macro_use]
 extern crate prettytable;
 
-extern crate unic;
-extern crate unic_cli;
-
 use clap::Arg;
 use prettytable::format::TableFormat;
 use prettytable::Table;
 
 use unic::char::property::EnumeratedCharProperty;
-use unic::ucd::{GeneralCategory, Name};
+use unic::ucd::{name_aliases_of, GeneralCategory, Name, NameAliasType};
 
 fn main() {
     let app = app_from_crate!()
@@ -62,14 +59,17 @@ fn main() {
     */
 
     string.chars().for_each(|chr| {
-        let name = Name::of(chr)
-            .map(|n| n.to_string())
-            .unwrap_or_else(|| "<none>".to_owned());
+        let display_name = Name::of(chr).map(|n| n.to_string()).unwrap_or_else(|| {
+            match name_aliases_of(chr, NameAliasType::NameAbbreviations) {
+                Some(abbrs) => abbrs[0].to_owned(),
+                None => "<none>".to_owned(),
+            }
+        });
 
         table.add_row(row![
             cb  -> &format!("{}", chr),
             rFr -> &format!("U+{:04X}", chr as u32),
-            l   -> &name,
+            l   -> &display_name,
             l   -> &GeneralCategory::of(chr).long_name()
         ]);
     });
